==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/96/96d497e30349f56263ddb5eefaace68e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/Assets/css/point.css */
class __TwigTemplate_8700e4276c4b3c1e88d557f274c3a79e extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield ".col-point-id, .col-pointtrigger-id {
    width: 75px;
}

.trigger-event-group-header {
    font-size: 1.1em;
    font-weight: bold;
}

#triggerEvents .trigger-event-row {
    padding: 20px;
    margin-bottom: 0 !important;
    border: 1px solid #ecf0f1;
    position: relative;
}

#triggerEvents .trigger-event-row .event-label {
    font-size: 1.1em;
    font-weight: bold;
    display: block;
}

#triggerEvents .trigger-event-row .event-descr {
    font-size: 0.9em;
    display: block;
}

#triggerEvents .trigger-event-row:hover {
    background-color: #ecf0f1;
}

#triggerEvents .trigger-event-row.bg-danger:hover {
    background-color: #f2d4d2;
}

#triggerEvents .form-buttons {
    float: right;
    position: absolute; 
    top: 50%;             
    right: 20px;          
    transform: translateY(-50%);
}

.col-pointtrigger-color {
    width: 50px;
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/Assets/css/point.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/Assets/css/point.css", "/var/www/mautic-ktn/app/bundles/PointBundle/Assets/css/point.css");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/96/96d497e30349f56263ddb5eefaace68e.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/PointBundle/Assets/css/point.css */
class __TwigTemplate_8700e4276c4b3c1e88d557f274c3a79e extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield ".col-point-id, .col-pointtrigger-id {
    width: 75px;
}

.trigger-event-group-header {
    font-size: 1.1em;
    font-weight: bold;
}

#triggerEvents .trigger-event-row {
    padding: 20px;
    margin-bottom: 0 !important;
    border: 1px solid #ecf0f1;
    position: relative;
}

#triggerEvents .trigger-event-row .event-label {
    font-size: 1.1em;
    font-weight: bold;
    display: block;
}

#triggerEvents .trigger-event-row .event-descr {
    font-size: 0.9em;
    display: block;
}

#triggerEvents .trigger-event-row:hover {
    background-color: #ecf0f1;
}

#triggerEvents .trigger-event-row.bg-danger:hover {
    background-color: #f2d4d2;
}

#triggerEvents .form-buttons {
    float: right;
    position: absolute; 
    top: 50%;             
    right: 20px;          
    transform: translateY(-50%);
}

.col-pointtrigger-color {
    width: 50px;
}";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/PointBundle/Assets/css/point.css";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/PointBundle/Assets/css/point.css", "/var/www/html/mauticGIT-Test/app/bundles/PointBundle/Assets/css/point.css");
    }
}
